@@ -369,8 +369,10 @@ class DataExploreView(QDockWidget):
                 global _frame
                 tabWidget = _frame.centralWidget ()
                 widget = ext.create_editor(tabWidget)
-                widget.on_init(node)
-                tabWidget.addTab(widget, node.get_name())
+                if tabWidget.indexOf(widget) == -1:
+                    widget.on_init(node)
+                    tabWidget.addTab(widget, node.get_name())
+                tabWidget.setCurrentWidget(widget)
                 break
 
     def itemPressed(self, item, col):
