@@ -24,7 +24,8 @@ class MainWindow(QMainWindow):
         self.menu = self.menuBar()
 
         exts = context.find_extension("PL::Basic::Menu")
-        for ext in exts:
+        sort_exts = sorted(exts, key=lambda ext: ext.priorty())
+        for ext in sort_exts:
             ext.add_menu(self.menu)
 
         self._tool_bar = QToolBar()
@@ -67,8 +68,12 @@ class MyApp:
         app = QApplication(sys.argv)
 
         window = MainWindow()
-        window.resize(800, 600)
-        window.show()
+        
+        window.showMaximized()
+        window.resize(10000,10000)
+        print(window.size())
+        print(window.maximumSize())
+        #window.showMaximized()
 
         sys.exit(app.exec_())
             
@@ -82,6 +87,8 @@ class MyTest:
 
 MenuExtension = '''
 class MenuExtension:
+    def priorty(self):
+        return 1000
     def add_menu(self, menu_bar):
         print("Hello in add_menu!")
 '''
