@@ -317,6 +317,7 @@ class ObjectController(QWidget):
         del self.d_ptr
 
     def setObject(self, object):
+        print(object)
         if (self.d_ptr.m_object == object):
             return
 
@@ -332,6 +333,53 @@ class ObjectController(QWidget):
         if (not self.d_ptr.m_object):
             return
 
+        print(self.d_ptr.m_object.metaObject())
+        metaObject = self.d_ptr.m_object.metaObject()
+        for idx in range(metaObject.propertyOffset(), metaObject.propertyCount(), 1):
+                print(idx)
+                metaProperty = metaObject.property(idx)
+                print(metaProperty)
+                type = metaProperty.userType()
+                print('type:', type)
+                subProperty = 0
+                print('property name:', metaProperty.name())
+                print('is Enum:', metaProperty.isEnumType())
+                print('is Flag:', metaProperty.isFlagType())
+                print('is Readable:', metaProperty.isReadable())
+                print('is writeble:',  metaProperty.isWritable())
+                print('is designable:', metaProperty.isDesignable())
+                print('value:', metaProperty.read(object))
+
+
+                if (not metaProperty.isReadable()):
+                    subProperty = self.m_readOnlyManager.addProperty(QVariant.String, metaProperty.name())
+                    subProperty.setValue("< Non Readable >")
+                elif (metaProperty.isEnumType()):
+                    if (metaProperty.isFlagType()):
+                        metaEnum = metaProperty.enumerator()
+                        valueMap = QMap()
+                        flagNames = QList()
+                        for i in range(metaEnum.keyCount()):
+                            value = metaEnum.value(i)
+                            print('Enum value:', value)
+                            print('Enum key:', metaEnum.key(i))
+                    
+                    else: 
+                        subProperty = self.m_manager.addProperty(QtVariantPropertyManager.enumTypeId(), metaProperty.name())
+                        metaEnum = metaProperty.enumerator()
+                        valueMap = QMap() # dont show multiple enum values which have the same values
+                        enumNames = QList()
+                        for i in range(metaEnum.keyCount()):
+                            value = metaEnum.value(i)
+                            if (not valueMap.contains(value)):
+                                valueMap[value] = True
+                                enumNames.append(metaEnum.key(i))
+
+                        subProperty.setAttribute("enumNames", enumNames)
+                        subProperty.setValue(self.enumToInt(metaEnum, metaProperty.read(self.m_object)))
+
+
+
         self.d_ptr.addClassProperties(self.d_ptr.m_object.metaObject())
 
         self.d_ptr.restoreExpandedState()
